from django.contrib.auth.models import Group
from django.contrib.auth import get_user_model
from django.contrib.auth.hashers import make_password
from tickets.models import Ticket, TicketList
from datetime import datetime

def create_metaservice_default_data():
    create_metaservice_initial_groups()
    create_metaservice_ticket_lists()


def create_metaservice_initial_groups():
    groups = [
        ('METASERVICE-ADMIN', 21),
        ('METASERVICE-SUPERVISOR', 22),
        ('METASERVICE-SUPPORT', 23),
        ('METASERVICE-TECHSUPPORT', 24),
        ('PARTNER-ADMIN', 31),
        ('PARTNER-SUPERVISOR', 32),
        ('PARTNER-SUPPORT', 33),
        ('PARTNER-TECHSUPPORT', 34),
        ('PROVIDER', 41),
        ('CLIENT', 51),
        ('GUEST', 61),
        ('TEST', 99)
    ]

    for name, pk in groups:
        group, created = Group.objects.get_or_create(name=name, defaults={'pk': pk})
        if not created:
            print(f"Group {name} already exists.")


def create_metaservice_ticket_lists():
    ticket_data = [
        # METASERVICE
        (2101, 'Активация партнеров (NEG_REQUEST)', 'METASERVICE-ADMIN'),
        (2102, 'Права в сервисе (ACCESS_REQUEST)', 'METASERVICE-ADMIN'),
        (2103, 'Проверка документов (ST_REQUEST)', 'METASERVICE-ADMIN'),
        (2201, 'Активность пользователей (ST_REQUEST)', 'METASERVICE-SUPERVISOR'),
        (2202, 'Оперативный доступ (ST_REQUEST)', 'METASERVICE-SUPERVISOR'),
        (2203, 'Оперативный доступ экстра (ACCESS_REQUEST)', 'METASERVICE-SUPERVISOR'),
        (2204, 'Права сервиса (ST_REQUEST)', 'METASERVICE-SUPERVISOR'),
        (2205, 'Проверка документов (ST_REQUEST)', 'METASERVICE-SUPERVISOR'),
        (2301, 'Входящие обычные заявки (ST_REQUEST)', 'METASERVICE-SUPPORT'),
        (2302, 'Заявки на услуги сервиса (SERVICE_REQUEST)', 'METASERVICE-SUPPORT'),
        (2401, 'Входящие технические заявки (ST_REQUEST)', 'METASERVICE-TECHSUPPORT'),
        # PARTNER
        (3101, 'Документы исполнителей (ST_REQUEST)', 'PARTNER-ADMIN'),
        (3102, 'Документы ресурсов (ST_REQUEST)', 'PARTNER-ADMIN'),
        (3103, 'Права в партнерке (ACCESS_REQUEST)', 'PARTNER-ADMIN'),
        (3201, 'Активность внутри партнера (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3202, 'Документы исполнителей (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3203, 'Документы ресурсов (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3204, 'Доступ внутри партнера (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3205, 'Оперативный доступ (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3206, 'Оперативный доступ экстра (ST_REQUEST)', 'PARTNER-SUPERVISOR'),
        (3207, 'Ручное подтверждение заявок (ACCESS-REQUEST)', 'PARTNER-SUPERVISOR'),
        (3401, 'Входящие технические заявки (ST_REQUEST)', 'PARTNER-TECHSUPPORT'),
    ]

    for pk, name, group_name in ticket_data:
        group = Group.objects.get(name=group_name)
        # Проверяем существование тикета с таким же name и group
        ticket_exists = TicketList.objects.filter(group=group, name=name).exists()

        if not ticket_exists:
            TicketList.objects.create(pk=pk, name=name, group=group)


def create_metaservice_test_users():
    """
    Создает тестовых пользователей
    """

    User = get_user_model()

    # Создание админа
    if not get_user_model().objects.filter(phone_number="11111111111").exists():
        admin = get_user_model().objects.create_superuser(
            'admin',
            'admin@admin.com',
            'Sharix!',
            phone_number="11111111111"
        )

    password = make_password("sharix-open-test")
    test_group = Group.objects.get(pk=99)

    # Группа, в которой надо создать пользователя и их количество
    test_users = [
        ('METASERVICE-ADMIN', 1),
        ('METASERVICE-SUPERVISOR', 3),
        ('METASERVICE-SUPPORT', 3),
        ('METASERVICE-TECHSUPPORT', 3),

        ('PARTNER-ADMIN', 1),
        ('PARTNER-SUPERVISOR', 3),
        ('PARTNER-SUPPORT', 3),
        ('PARTNER-TECHSUPPORT', 3),

        ('PROVIDER', 3),
        ('CLIENT', 3),
        ('GUEST', 3)
    ]

    for test_user in test_users:
        group_name = test_user[0]
        group = Group.objects.get(name=group_name)

        for i in range(1, test_user[1] + 1):
            user, created = User.objects.get_or_create(
                phone_number=f"{group.pk}0{i}",
                defaults={
                    'last_name': i,
                    'first_name': group_name,
                    'email': f"test-{group_name.lower()}-{i}@domain.org",
                    'username': f"test-{group_name.lower()}-{i}",
                    'middle_name': "Test",
                    'password': password
                }
            )

            if created:
                user.groups.add(
                    test_group,
                    group
                )

    # Создание тикета о создании пользователей
    if not Ticket.objects.all().exists():
        # test-metaservice-admin-1
        user = get_user_model().objects.filter(phone_number=2101).get()
        ticket_list = TicketList.objects.get(pk=2103)

        Ticket.objects.create(
            title=f"Создание тестовых пользователей",
            ticket_list=ticket_list,
            ticket_type=1,  # ST_REQUEST
            due_date=datetime.now().date(),
            created_by=user,
            note=f"""
                Успешное создание тестовых пользователей
            """
        )
