from django.contrib.auth import get_user_model
from django.db import models

from tickets.models import Ticket

from dbsynce.docs.database.company import Company as HelpTexts
from core.settings_vars import METASERVICE_ID

class Company(models.Model):
    """
    Company - это таблица с партнерами сервисов. Партнер сервиса -
    юридическое лицо или ИП, которое непосредственно организует работу с
    исполнителями и отвечает перед клиентами и перед сервисом за качество
    оказанных услуг. Юридически это лица, фактически оказывающие услуги
    по договору.
    """

    # ID METASERVICE
    # FIXME: id_metaservice должно принимать текущий идентификатор метасервиса, на котором происходит создание записи
    id_metaservice = models.PositiveIntegerField(
        default=METASERVICE_ID,
        help_text=HelpTexts.id_metaservice
    )

    # DATA
    requirements = models.CharField(
        "Ограничения",
        max_length=150,
        default="DS01y04y05y06y07yMPUCS13MPUB",
        help_text=HelpTexts.requirements
    )
    status = models.CharField(
        "Статус",
        max_length=150,
        default="deactivated",
        help_text=HelpTexts.status
    )
    legal_name = models.CharField(
        "Название организации",
        max_length=150,
        help_text=HelpTexts.legal_name
    )
    address = models.CharField(
        "Юридический адрес",
        max_length=150,
        help_text=HelpTexts.address
    )
    inn = models.CharField(
        "ИНН компании",
        max_length=12,
        unique=True,
        help_text=HelpTexts.inn
    )
    kpp = models.CharField(
        "КПП компании",
        max_length=9,
        help_text=HelpTexts.kpp
    )
    ogrn = models.CharField(
        "ОГРН компании",
        max_length=15,
        help_text=HelpTexts.ogrn
    )
    bank_name = models.CharField(
        "Название банка",
        max_length=150,
        help_text=HelpTexts.bank_name
    )
    bik = models.CharField(
        "БИК компании",
        max_length=11,
        help_text=HelpTexts.bik
    )
    rs = models.CharField(
        "Расчетный счет",
        max_length=20,
        help_text=HelpTexts.rs
    )
    ks = models.CharField(
        "Корреспондентский счет",
        max_length=20,
        help_text=HelpTexts.ks
    )
    tax_method = models.IntegerField(
        help_text=HelpTexts.tax_method
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text="Доступно ли для хранения в глобальном сервисе / Нужна синхронизация данных"
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text="Доступно ли для планирования в цепочке с другими услугами в глобальном сервисе"
    )

    # FK
    repr = models.ForeignKey(
        get_user_model(),
        blank=True,
        verbose_name="Представитель организации",
        on_delete=models.DO_NOTHING,
        help_text="Уникальный идентификатор представителя компании"
    )
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.SET_NULL,
        blank=True,
        null=True,
        help_text="ID заявки, привязанной к текущей записи",
        verbose_name="Связанный тикет"
    )

    def deactivate(self):
        self.status = "deactivated"
        self.save()

    class Meta:
        db_table = "company"
        verbose_name = "Компания"
        verbose_name_plural = "Компании"
