from django.contrib.auth import get_user_model
from django.db import models

from dbsynce.models.client import Client
from dbsynce.models.company import Company
from dbsynce.models.provider import Provider
from dbsynce.models.service import Service
from dbsynce.models.service_category import ServiceCategory
from tickets.models import Ticket

from dbsynce.docs.database.orders import Orders as HelpTexts
from core.settings_vars import METASERVICE_ID


class Orders(models.Model):
    """
    Orders - таблица с заказами
    """

    # ID METASERVICE
    id_metaservice = models.PositiveIntegerField(
        default=METASERVICE_ID,
        help_text=HelpTexts.id_metaservice
    )

    # DATA
    status = models.CharField(
        max_length=150,
        help_text=HelpTexts.status
    )
    title = models.CharField(
        max_length=150,
        help_text=HelpTexts.title,
        default='Заголовок'
    )
    note = models.CharField(
        max_length=150,
        help_text=HelpTexts.note,
        default='Записи'
    )
    time_created = models.DateTimeField(
        auto_now_add=True,
        help_text=HelpTexts.time_created
    )
    time_placed = models.DateTimeField(
        help_text=HelpTexts.time_placed
    )
    time_start = models.DateTimeField(
        null=True,
        help_text=HelpTexts.time_start
    )
    time_start_real = models.DateTimeField(
        null=True,
        help_text=HelpTexts.time_start_real
    )
    time_start_predicted = models.DateTimeField(
        null=True,
        help_text=HelpTexts.time_start_predicted
    )
    time_finish_real = models.DateTimeField(
        null=True,
        help_text=HelpTexts.time_finish_real
    )
    time_finish_predicted = models.DateTimeField(
        help_text=HelpTexts.time_finish_predicted
    )
    real_price = models.FloatField(
        help_text=HelpTexts.real_price
    )
    predicted_price = models.FloatField(
        help_text=HelpTexts.predicted_price
    )
    # NOTE: Возможно в будующем можнос сделать символом
    asap = models.BooleanField(
        default=False,
        help_text=HelpTexts.asap
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_global
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_visible
    )

    # FK
    ticket = models.ForeignKey(
        Ticket,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.ticket
    )
    service = models.ForeignKey(
        Service,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.service
    )
    service_category = models.ForeignKey(
        ServiceCategory,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.service_category
    )
    client = models.ForeignKey(
        Client,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.client
    )
    provider = models.ForeignKey(
        Provider,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.provider
    )
    receiver = models.ForeignKey(
        get_user_model(),
        null=True,
        related_name="user",
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.receiver
    )
    company = models.ForeignKey(
        Company,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text=HelpTexts.company
    )

    class Meta:
        db_table = "orders"
        verbose_name = "Заказ"
        verbose_name_plural = "Заказы"
