from django.db import models

from dbsynce.models.resource import Resource
from dbsynce.models.service_category import ServiceCategory
from tickets.models import Ticket

from dbsynce.docs.database.service import Service as HelpTexts
from core.settings_vars import METASERVICE_ID


class Service(models.Model):
    """
    service - спецификация услуги каждого конкретного поставщика 
    (например, в рамках сервиса многие могут предоставлять услуги перевозки, 
    но конкретный шаблон с конкретным тарифом относится к отдельному перевозчику)
    """

    # ID METASERVICE
    id_metaservice = models.PositiveIntegerField(
        default=METASERVICE_ID,
        help_text=HelpTexts.id_metaservice
    )

    # DATA
    price_type = models.CharField(
        max_length=100,
        help_text=HelpTexts.price_type
    )
    price_km = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        help_text=HelpTexts.price_km
    )
    price_min = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        help_text=HelpTexts.price_min
    )
    price_amount = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        help_text=HelpTexts.price_amount
    )
    company_comission = models.FloatField(
        help_text=HelpTexts.company_comission
    )
    requirements = models.CharField(
        max_length=150,
        help_text=HelpTexts.requirements
    )
    status = models.CharField(
        max_length=150,
        help_text=HelpTexts.status
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_global
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_visible
    )

    # FK
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.ticket_status
    )
    resource = models.ForeignKey(
        Resource,
        on_delete=models.DO_NOTHING,
        blank=True,
        null=True,
        help_text=HelpTexts.resource
    )
    service_category = models.ForeignKey(
        ServiceCategory,
        on_delete=models.DO_NOTHING,
        help_text=HelpTexts.service_category
    )

    class Meta:
        db_table = "service"
        verbose_name = "Услуга"
        verbose_name_plural = "Услуги"
