from django.db import models

from tickets.models import Ticket

from dbsynce.docs.database.service_category import ServiceCategory as HelpTexts
from core.settings_vars import METASERVICE_ID


class ServiceCategory(models.Model):
    """
    Перечень типов услуг
    """

    # ID METASERVICE
    id_metaservice = models.PositiveIntegerField(
        default=METASERVICE_ID,
        help_text=HelpTexts.id_metaservice
    )

    # DATA
    codename = models.CharField(
        max_length=255,
        help_text=HelpTexts.codename
    )
    requirements = models.CharField(
        max_length=300,
        help_text=HelpTexts.requirements
    )
    status = models.CharField(
        max_length=150,
        help_text=HelpTexts.status
    )
    caption = models.CharField(
        max_length=255,
        help_text=HelpTexts.caption
    )
    description = models.TextField(
        blank=True,
        help_text=HelpTexts.description
    )
    link_agreement = models.CharField(
        max_length=400,
        help_text=HelpTexts.link_agreement
    )
    price_type = models.CharField(
        max_length=150,
        help_text=HelpTexts.price_type
    )
    metaservice_comission = models.FloatField(
        help_text=HelpTexts.metaservice_comission
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_global
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text=HelpTexts.is_visible
    )

    # FK
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text=HelpTexts.ticket_status
    )

    class Meta:
        db_table = "service_category"
        verbose_name = "Тип услуги"
        verbose_name_plural = "Типы услуг"
